@@ -1,16 +1,22 @@
-/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
- * $Id: ClassFile.java 490 2006-10-01 16:08:04Z metlov $
- *
- * This file is part of the Java Expressions Library (JEL).
- *   For more information about JEL visit :
- *    http://kinetic.ac.donetsk.ua/JEL/
- *
- * (c) 1998 -- 2007 by Konstantin Metlov(metlov@kinetic.ac.donetsk.ua);
- *
- * JEL is Distributed under the terms of GNU General Public License.
- *    This code comes with ABSOLUTELY NO WARRANTY.
- *  For license details see COPYING file in this directory.
- */
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+*   This file is part of the Java Expressions Library (JEL).
+*   For more information about JEL visit : http://fti.dn.ua/JEL/
+*
+*   Copyright (C) 1998, 1999, 2000, 2001, 2003, 2006, 2007, 2009 Konstantin L. Metlov
+*
+*   This program is free software: you can redistribute it and/or modify
+*   it under the terms of the GNU General Public License as published by
+*   the Free Software Foundation, either version 3 of the License, or
+*   (at your option) any later version.
+*
+*   This program is distributed in the hope that it will be useful,
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*   GNU General Public License for more details.
+*
+*   You should have received a copy of the GNU General Public License
+*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 package gnu.jel;
 
@@ -198,7 +204,7 @@ public class ClassFile implements Cloneable {
       // clone containers
       res.Items=new HashMap<Object,Integer>(res.Items);
       res.UTFs=new HashMap<String,Integer>(res.UTFs);
-      res.paramsVars=(int [])res.paramsVars.clone();
+      res.paramsVars=res.paramsVars.clone();
       res.branchStack=res.branchStack.copy();
 
       if (Debug.enabled)
@@ -213,7 +219,7 @@ public class ClassFile implements Cloneable {
       constPoolData.writeTo(res.constPoolData);
       res.constPool=new DataOutputStream(res.constPoolData);
 
-      res.text=(byte[]) res.text.clone();
+      res.text=res.text.clone();
       
     } catch (IOException exc) {
       if (Debug.enabled)
@@ -437,9 +443,9 @@ public class ClassFile implements Cloneable {
     specialMethods=new Member[specialMds.length];
     
     {
-      Class definingClass=null;
+      Class<?> definingClass=null;
       String name=null;
-      Class[] params=null;
+      Class<?>[] params=null;
       int i=0;
       try {
         for (i=0;i<specialMds.length;i++) {
