@@ -1,17 +1,22 @@
-/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*- 
-/*
- * $Id: Parser.java 490 2006-10-01 16:08:04Z metlov $
- *
- * This file is part of the Java Expressions Library (JEL).
- *   For more information about JEL visit :
- *    http://kinetic.ac.donetsk.ua/JEL/
- *
- * (c) 1998 -- 2007 by Konstantin L. Metlov
- *
- * JEL is Distributed under the terms of GNU General Public License.
- *    This code comes with ABSOLUTELY NO WARRANTY.
- *  For license details see COPYING file in this directory.
- */
+/* -*- Mode: Java; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 2 -*-
+*   This file is part of the Java Expressions Library (JEL).
+*   For more information about JEL visit : http://fti.dn.ua/JEL/
+*
+*   Copyright (C) 1998, 1999, 2000, 2001, 2003, 2006, 2007, 2009 Konstantin L. Metlov
+*
+*   This program is free software: you can redistribute it and/or modify
+*   it under the terms of the GNU General Public License as published by
+*   the Free Software Foundation, either version 3 of the License, or
+*   (at your option) any later version.
+*
+*   This program is distributed in the hope that it will be useful,
+*   but WITHOUT ANY WARRANTY; without even the implied warranty of
+*   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+*   GNU General Public License for more details.
+*
+*   You should have received a copy of the GNU General Public License
+*   along with this program.  If not, see <http://www.gnu.org/licenses/>.
+*/
 
 package gnu.jel;
 
@@ -66,7 +71,7 @@ public class Parser {
   public Object val;
   
   /**
-   * type of the currect token
+   * type of the current token
    */
   public int type;
   
@@ -212,6 +217,7 @@ public class Parser {
         type=-1; return;
       case ' ':
       case '\r':
+      case '\t':
       case '\n':
         read(); // just ignored
         ct_column=column; // adjust start token
@@ -515,7 +521,6 @@ public class Parser {
           consume(-1);  // overflow (make better overflow reporting)
         value=(value<<4)+(10+Character.toLowerCase((char)c)-'a');
         break;
-
       case '.':
         if (base==16)
           break outerLoop; // illegal character, error will appear later
@@ -549,6 +554,9 @@ public class Parser {
         if (value<=127) val=new Byte((byte)value);
         else if (value<=32767) val=new Short((short)value);
         else if (value<=2147483647) val=new Integer((int)value);
+        else if (((base==16) || (base==8)) &&
+                 (value<=4294967295L)) // we allow HEX and octal ints
+          val=new Integer((int)value); // to overflow to negative values
         else consume(-1); // overflow (make better overflow reporting)
         break outerLoop;
       };
@@ -665,7 +673,7 @@ public class Parser {
         while(true)
           switch(c) {
           case -1:  break outerLoop;
-          case ' ': case '\n': case '\r': read(); break;
+          case ' ': case '\t': case '\n': case '\r': read(); break;
           default:  break ws2;
           };
         
@@ -680,7 +688,7 @@ public class Parser {
         while(true)
           switch(c) {
           case -1:  break outerLoop;
-          case ' ': case '\n': case '\r': read(); break;
+          case ' ': case '\t': case '\n': case '\r': read(); break;
           default:
             break ws3;
           };
@@ -709,7 +717,7 @@ public class Parser {
       // we now match beginning of '(', <ID>, '.', '\'', '\"', <NUMBER>
       while (true)
         switch (c) {
-        case ' ': case '\n': case '\r': read(); break;
+        case ' ': case '\t': case '\n': case '\r': read(); break;
         case ']': 
           result=true;
         case '(': case '.': case '\'': case '\"':
@@ -751,7 +759,7 @@ public class Parser {
       err_col=ct_column-1; // this should be now set to <EOF>
 
       // remove TSB at return if present
-      if (((OP)paramOPs.peek()).resID==10)
+      if (paramOPs.peek().resID==10)
         paramOPs.push(new OPunary(paramOPs,11,null,false));
       // set result type
       if (resultType!=null) 
@@ -775,7 +783,7 @@ public class Parser {
       Debug.check(paramOPs.size()==1,
                    "There must be only a single item left in paramOPs stack.");
     
-    return (OP)paramOPs.pop();
+    return paramOPs.pop();
   };
   
   private void consumeT(int t) throws CompilationException {
@@ -916,7 +924,7 @@ public class Parser {
       if ((typeID==8) &&
           (
            (clazz=(lib.cnmap==null?null:
-                   (Class)lib.cnmap.get(typeAccum.substring(accumStrt))
+                   lib.cnmap.get(typeAccum.substring(accumStrt))
                    )
             )==null
            )
@@ -998,7 +1006,7 @@ public class Parser {
     }; // end if accDV!=null
 
     if (!inDVmatch) {
-      if (afterDot) resolveIn=((OP)paramOPs.peek()).resType;
+      if (afterDot) resolveIn=paramOPs.peek().resType;
       // start prepating a call to an object's method x.image
       paramsStart=paramOPs.size();
     };
@@ -1076,7 +1084,7 @@ public class Parser {
     // with old (pre 0.9.9) dynamic variables interface and 
     // is subject for removal in JEL 1.0
     if (lib.resolver instanceof DVMap)
-      varObj=((DVMap)lib.resolver).translate(varName);
+      varObj=lib.resolver.translate(varName);
     else
       varObj=varName;
 
@@ -1094,7 +1102,7 @@ public class Parser {
     Class[] params=new Class[np];
 
     for(int i=np-1;i>=0;i--) {
-      OP cop=(OP)paramOPs.pop();
+      OP cop=paramOPs.pop();
       xchgOP.push(cop);
       params[i]=cop.resType;
     }
